package com.gic.store.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.download.utils.OperationResultUtils;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.dto.StoreSearchDTO;
import com.gic.store.dto.StoreTagDTO;
import com.gic.store.dto.StoreWidgetDTO;
import com.gic.store.service.StoreApiService;
import com.gic.store.service.StoreTagApiService;
import com.gic.store.service.StoreWidgetApiService;
import com.gic.store.web.vo.StoreTagVO;
import org.apache.commons.lang.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/store-tag")
public class StoreTagController {
    private static final Logger LOGGER = LogManager.getLogger(StoreTagController.class);

    @Autowired
    private StoreTagApiService storeTagApiService;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;
    @Autowired
    private StoreApiService storeApiService;

    @RequestMapping("/save-store-tag")
    public RestResponse save(StoreTagDTO dto) {
        dto.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
        return OperationResultUtils.operationResult(storeTagApiService.save(dto), OperationResultUtils.LOG_NEW + "门店标签",
                dto.getStoreTagName());
    }

    @RequestMapping("/edit-store-tag")
    public RestResponse edit(StoreTagDTO dto) {
        return OperationResultUtils.operationResult(storeTagApiService.update(dto),
                OperationResultUtils.LOG_EDIT + "门店标签", dto.getStoreTagName());
    }

    @RequestMapping("/delete-store-tag")
    public RestResponse delete(Integer storeTagId) {
        ServiceResponse<String> result = storeTagApiService.delete(storeTagId);
        return OperationResultUtils.operationResult(result, OperationResultUtils.LOG_DELETE + "门店标签",
                OperationResultUtils.getOperationObject(result));
    }

    @RequestMapping("/list-store-tag")
    public RestResponse list() {
        return ResultControllerUtils.commonResult(
                storeTagApiService.listByEnterprise(UserDetailUtils.getUserDetail().getEnterpriseId()),
                StoreTagVO.class);
    }

    @RequestMapping("/list-store-by-tag")
    public RestResponse listStoreByTag(Integer storeTagId, String search, @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum, @RequestParam(value = "pageSize", defaultValue = "20") Integer pageSize) {
        ServiceResponse<StoreTagDTO> result = storeTagApiService.getByStoreTagId(storeTagId);
        if (result.isSuccess()) {
            ServiceResponse<StoreWidgetDTO> storeWidgetResult = storeWidgetApiService
                    .getStoreWidget(result.getResult().getStoreWidgetId());
            if (storeWidgetResult.isSuccess()) {
                StoreWidgetDTO storeWidgetDTO = storeWidgetResult.getResult();
                String authSearchParam = storeWidgetDTO.getAuthSearchParam();
                String searchParam = storeWidgetDTO.getSearchParam();
                StoreSearchDTO dto = new StoreSearchDTO();
                //名称
                dto.setSearch(search);
                //代码
                dto.setStoreCode(search);
                dto.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
                if(StringUtils.isNotBlank(authSearchParam) && !"{}".equals(authSearchParam)){
                    dto.setAuthSearchJson(authSearchParam);
                }
                dto.setSearchJson(searchParam);
                return ResultControllerUtils.commonResult(this.storeApiService.listStore(dto, pageNum, pageSize));
            }
            return EnterpriseRestResponse.failure(storeWidgetResult);
        }
        return EnterpriseRestResponse.failure(result);
    }
}
